aboutsummaryrefslogtreecommitdiffstats
path: root/libkeccak_hmac_unmarshal.c
diff options
context:
space:
mode:
Diffstat (limited to 'libkeccak_hmac_unmarshal.c')
-rw-r--r--libkeccak_hmac_unmarshal.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkeccak_hmac_unmarshal.c b/libkeccak_hmac_unmarshal.c
index e64cd08..81d2121 100644
--- a/libkeccak_hmac_unmarshal.c
+++ b/libkeccak_hmac_unmarshal.c
@@ -3,14 +3,14 @@
/**
* Unmarshal a `libkeccak_hmac_state_t` from a buffer
*
* @param state The slot for the unmarshalled state, must not be initialised (memory leak otherwise)
* @param data The input buffer
* @return The number of bytes read from `data`, 0 on error
*/
size_t
-libkeccak_hmac_unmarshal(libkeccak_hmac_state_t *restrict state, const void *restrict data_)
+libkeccak_hmac_unmarshal(struct libkeccak_hmac_state *restrict state, const void *restrict data_)
{
const char *restrict data = data_;
size_t parsed, size, i;
@@ -3,14 +3,14 @@
/**
- * Unmarshal a `libkeccak_hmac_state_t` from a buffer
+ * Unmarshal a `struct libkeccak_hmac_state` from a buffer
*
* @param state The slot for the unmarshalled state, must not be initialised (memory leak otherwise)